==> wow_views-0.0.30.tar.gz: lib/screens/google_map/google_map.dart <==
// ignore_for_file: prefer_collection_literals

import 'dart:async';
import 'dart:ui' as ui;
import 'package:flutter/widgets.dart' as widgets;
import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:wowit/methods.dart';
import 'canvas_marker.dart';
import 'setup_marker.dart';

class MapLocation extends widgets.StatefulWidget {
  final List<SetUpMarker> setUpMarker;
  final String iconMarker;
  final Color color;

  const MapLocation(this.setUpMarker,
      {widgets.Key key, this.iconMarker = '', this.color = Colors.black})
      : super(key: key);

  @override
  _MapLocationState createState() => _MapLocationState();
}

class _MapLocationState extends widgets.State<MapLocation> {
  final Set<Marker> _marker = {};
  final double viewLocationSeletedDefaut = 19;

  final Completer<GoogleMapController> _controllerGoogleMap = Completer();

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    double latitude =
        widget.setUpMarker.isNotEmpty ? widget.setUpMarker[0].latitude : 0;
    double longitude =
        widget.setUpMarker.isNotEmpty ? widget.setUpMarker[0].longitude : 0;

    var target = LatLng(latitude, longitude);

    return Scaffold(
      backgroundColor: Colors.white,
      body: SizedBox(
        height: size.height / 4,
        width: size.width,
        child: GoogleMap(
          gestureRecognizers: Set()..add(Factory<PanGestureRecognizer>(() => PanGestureRecognizer())),
          scrollGesturesEnabled: true,
          zoomGesturesEnabled: true,
          tiltGesturesEnabled: true,
          initialCameraPosition:
              CameraPosition(target: target, zoom: viewLocationSeletedDefaut),
          onMapCreated: (GoogleMapController controller) {
            _controllerGoogleMap.complete(controller);
            createMark().then((value) {
              setState(() {});
            });
          },
          markers: _marker,
        ),
      ),
    );
  }

  Future<ui.Image> loadUiImage(String imageAssetPath) {
    widgets.Image widgetsImage =
        widgets.Image.network(Methods.getURL(imageAssetPath), scale: 0.5);
    Completer<ui.Image> completer = Completer<ui.Image>();
    widgetsImage.image
        .resolve(const widgets.ImageConfiguration(size: ui.Size(10, 10)))
        .addListener(
            widgets.ImageStreamListener((widgets.ImageInfo info, bool _) {
      completer.complete(info.image);
    }));
    return completer.future;
  }

  Future createMark() async {
    for (int i = 0; i < widget.setUpMarker.length; i++) {
      var maker = widget.setUpMarker[i];
      maker.ggMaker = await createMarkerItem(maker);
      _marker.add(maker.ggMaker);
    }
  }

  Future<Marker> createMarkerItem(SetUpMarker maker) async {
    BitmapDescriptor bitmapDescriptor;
    bitmapDescriptor = await canvasMarker(maker, maker.textValue);

    return Marker(
        markerId: MarkerId(maker.id.toString()),
        icon: bitmapDescriptor,
        position: LatLng(maker.latitude, maker.longitude),
        onTap: () async {
          for (var itemMarker in widget.setUpMarker) {
            itemMarker.selected = itemMarker.id == maker.id;
          }
          setState(() {});
        });
  }
}

==> wow_views-0.0.38.tar.gz: lib/screens/google_map/google_map.dart <==
// ignore_for_file: prefer_collection_literals

import 'dart:async';
import 'dart:ui' as ui;
import 'package:flutter/widgets.dart' as widgets;
import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:wowit/methods.dart';
import 'canvas_marker.dart';
import 'setup_marker.dart';

class MapLocation extends widgets.StatefulWidget {
  final List<SetUpMarker> setUpMarker;
  final String iconMarker;
  final Color color;

  const MapLocation(this.setUpMarker,
      {widgets.Key? key, this.iconMarker = '', this.color = Colors.black})
      : super(key: key);

  @override
  _MapLocationState createState() => _MapLocationState();
}

class _MapLocationState extends widgets.State<MapLocation> {
  final Set<Marker> _marker = {};
  final double viewLocationSeletedDefaut = 19;

  final Completer<GoogleMapController> _controllerGoogleMap = Completer();

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    double latitude =
        widget.setUpMarker.isNotEmpty ? widget.setUpMarker[0].latitude : 0;
    double longitude =
        widget.setUpMarker.isNotEmpty ? widget.setUpMarker[0].longitude : 0;

    var target = LatLng(latitude, longitude);

    return Scaffold(
      backgroundColor: Colors.white,
      body: SizedBox(
        height: size.height / 4,
        width: size.width,
        child: GoogleMap(
          gestureRecognizers: Set()
            ..add(Factory<PanGestureRecognizer>(() => PanGestureRecognizer())),
          scrollGesturesEnabled: true,
          zoomGesturesEnabled: true,
          tiltGesturesEnabled: true,
          initialCameraPosition:
              CameraPosition(target: target, zoom: viewLocationSeletedDefaut),
          onMapCreated: (GoogleMapController controller) {
            _controllerGoogleMap.complete(controller);
            createMark().then((value) {
              setState(() {});
            });
          },
          markers: _marker,
        ),
      ),
    );
  }

  Future<ui.Image> loadUiImage(String imageAssetPath) {
    widgets.Image widgetsImage =
        widgets.Image.network(Methods.getURL(imageAssetPath), scale: 0.5);
    Completer<ui.Image> completer = Completer<ui.Image>();
    widgetsImage.image
        .resolve(const widgets.ImageConfiguration(size: ui.Size(10, 10)))
        .addListener(
            widgets.ImageStreamListener((widgets.ImageInfo info, bool _) {
      completer.complete(info.image);
    }));
    return completer.future;
  }

  Future createMark() async {
    for (int i = 0; i < widget.setUpMarker.length; i++) {
      var maker = widget.setUpMarker[i];
      maker.ggMaker = await createMarkerItem(maker);
      if (maker.ggMaker != null) {
        _marker.add(maker.ggMaker!);
      }
    }
  }

  Future<Marker> createMarkerItem(SetUpMarker maker) async {
    BitmapDescriptor bitmapDescriptor;
    bitmapDescriptor = await canvasMarker(maker, maker.textValue);

    return Marker(
        markerId: MarkerId(maker.id.toString()),
        icon: bitmapDescriptor,
        position: LatLng(maker.latitude, maker.longitude),
        onTap: () async {
          for (var itemMarker in widget.setUpMarker) {
            itemMarker.selected = itemMarker.id == maker.id;
          }
          setState(() {});
        });
  }
}
